@@ -63,9 +63,7 @@ class DiscreteEnv(gym.Env):
     self.state=None    #self.df.sample(n=1, random_state=1).values.reshape(3,)
 
     #introduce some (short) length (time steps)
-    self.horizon=200
-    #self.is_end = False
-    
+    self.horizon=200 
     
     
 
@@ -75,9 +73,9 @@ class DiscreteEnv(gym.Env):
 
 
   
-#take an action with the environment
-#it returns the next observation, the immediate reward, whether the episode is over (done) and additional information    
-#"action" argument is one value in the range of the action space (logit transform)
+  #take an action with the environment
+  #it returns the next observation, the immediate reward, whether the episode is over (done) and additional information    
+  #"action" argument is one value in the range of the action space (logit transform)
   def step(self, action): 
 
       
@@ -109,11 +107,13 @@ class DiscreteEnv(gym.Env):
 
     self.Ynew_cumul = np.mean(Prob1)
     
-    reward = 0    
     #check if horizon is over, otherwise keep on going
     if self.horizon <= 0:
       done = True
-    reward = self.Ynew_cumul
+    else:
+      done = False
+    #depending on the value of self.state, apply a reward
+    reward = self.Ynew_cumul 
       
     self.state = self.df.sample(n=1, random_state=1).values.reshape(3,) 
  
@@ -127,8 +127,7 @@ class DiscreteEnv(gym.Env):
 #reset state and horizon    
   def reset(self):
     self.horizon = 200
-    self.done = False
-    
+        
     self.dfa = pd.DataFrame(dict(
             Xsa=truncnorm.rvs(a=0, b= math.inf,size=self.size),
             Xaa=truncnorm.rvs(a=0, b= math.inf,size=self.size),
